/*
-----------------------------------------------------
   Application Name: DIMG
          File Name: fpzip.cpp
         Start Date: 28/03/2010
       Last Changed: $LastChangedDate: 2010-03-30 22:11:50 +1300 (Tue, 30 Mar 2010) $
           Revision: $Revision: 185 $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2010
            License: GNU General Public License
   File Description: FPzip implementation
-----------------------------------------------------
        This file is part of DIMG.

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

File Notes:
------------------
*/


#include "FPzip.h"

#include "ziputil.h"

bool FPzip::fileIsSupported(QString filename) {
    qDebug() << "FPzip: Format support status requested for " << filename;

    QFileInfo fi;

    fi.setFile(filename);

    if (fi.completeSuffix().compare("imz",Qt::CaseInsensitive) != 0)
        return false;

    if (QFileInfo(filename).exists()) {

        QStringList fileList;
        getZipFileList(filename,&fileList);

        if (fileList.count() > 1) return false;

        if (QFileInfo(fileList.at(0)).completeSuffix().toUpper() == "IMA")
            return true;
    } else {
        return true;
    }

    return false;
}

QStringList FPzip::getNameFilters() {
    QStringList filters;

    filters << "Compressed Image Files (*.imz)";

    return filters;
}

ImageFile *FPzip::createImageFile(QString filename,
                                  ImageFilePlugin::LoadHints hints,
                                  long long expectedSize) {

    if (!fileIsSupported(filename)) {
        qDebug() << "WARNING: Specified file is unsupported by plugin.";
        return 0;
    }

    ZipImageFile *zif = new ZipImageFile(this);

    zif->open(filename,
              hints.testFlag(ImageFilePlugin::LH_Create));

    return zif;
}

Q_EXPORT_PLUGIN2(FPzip, FPzip)
